@@ -4,7 +4,7 @@ fn a_trivial_setup(context: &mut Context, initial: usize) {
 }
 
 #[step]
-fn a_trivial_cleanup(context: &mut Context, _initial: usize) {}
+fn a_trivial_cleanup(_context: &mut Context, _initial: usize) {}
 
 #[step]
 fn increment_counter(context: &mut Context) {
